pub struct NetworkClient<T> { /* private fields */ }Implementations
Sourceimpl NetworkClient<Channel>
impl NetworkClient<Channel>
Sourceimpl<T> NetworkClient<T>where
T: GrpcService<BoxBody>,
T::ResponseBody: Body + Send + 'static,
T::Error: Into<StdError>,
<T::ResponseBody as Body>::Error: Into<StdError> + Send,
impl<T> NetworkClient<T>where
T: GrpcService<BoxBody>,
T::ResponseBody: Body + Send + 'static,
T::Error: Into<StdError>,
<T::ResponseBody as Body>::Error: Into<StdError> + Send,
pub fn new(inner: T) -> Self
pub fn with_interceptor<F>(
inner: T,
interceptor: F,
) -> NetworkClient<InterceptedService<T, F>>where
F: Interceptor,
T: Service<Request<BoxBody>, Response = Response<<T as GrpcService<BoxBody>>::ResponseBody>>,
<T as Service<Request<BoxBody>>>::Error: Into<StdError> + Send + Sync,
Sourcepub fn send_gzip(self) -> Self
pub fn send_gzip(self) -> Self
Compress requests with gzip.
This requires the server to support it otherwise it might respond with an error.
Sourcepub fn accept_gzip(self) -> Self
pub fn accept_gzip(self) -> Self
Enable decompressing responses with gzip.
Sourcepub async fn listen(
&mut self,
request: impl IntoRequest<Null>,
) -> Result<Response<Streaming<Message>>, Status>
pub async fn listen( &mut self, request: impl IntoRequest<Null>, ) -> Result<Response<Streaming<Message>>, Status>
Receive messages coming from the network
Sourcepub async fn broadcast(
&mut self,
request: impl IntoRequest<BroadcastMessage>,
) -> Result<Response<Null>, Status>
pub async fn broadcast( &mut self, request: impl IntoRequest<BroadcastMessage>, ) -> Result<Response<Null>, Status>
Broadcast a message to the network
Sourcepub async fn propagate(
&mut self,
request: impl IntoRequest<PropagateMessage>,
) -> Result<Response<Null>, Status>
pub async fn propagate( &mut self, request: impl IntoRequest<PropagateMessage>, ) -> Result<Response<Null>, Status>
Propagate a message to the network and notify current receivers
Sourcepub async fn send(
&mut self,
request: impl IntoRequest<SendMessage>,
) -> Result<Response<Null>, Status>
pub async fn send( &mut self, request: impl IntoRequest<SendMessage>, ) -> Result<Response<Null>, Status>
Send a message to a specific target in the network
Sourcepub async fn alive_nodes(
&mut self,
request: impl IntoRequest<AliveNodesRequest>,
) -> Result<Response<AliveNodesResponse>, Status>
pub async fn alive_nodes( &mut self, request: impl IntoRequest<AliveNodesRequest>, ) -> Result<Response<AliveNodesResponse>, Status>
Retrieve network nodes considered alive