StateClient

Struct StateClient 

pub struct StateClient<T> { /* private fields */ }

Implementations

Source

impl StateClient<Channel>

pub async fn connect<D>(dst: D) -> Result<Self, Error>
where D: TryInto<Endpoint>, D::Error: Into<StdError>,

Attempt to create a new client by connecting to a given endpoint.

Source

impl<T> StateClient<T>
where T: GrpcService<BoxBody>, T::ResponseBody: Body + Send + 'static, T::Error: Into<StdError>, <T::ResponseBody as Body>::Error: Into<StdError> + Send,

pub fn new(inner: T) -> Self

pub fn with_interceptor<F>( inner: T, interceptor: F, ) -> StateClient<InterceptedService<T, F>>
where F: Interceptor, T: Service<Request<BoxBody>, Response = Response<<T as GrpcService<BoxBody>>::ResponseBody>>, <T as Service<Request<BoxBody>>>::Error: Into<StdError> + Send + Sync,

pub fn send_gzip(self) -> Self

Compress requests with gzip.

This requires the server to support it otherwise it might respond with an error.

pub fn accept_gzip(self) -> Self

Enable decompressing responses with gzip.

pub async fn echo( &mut self, request: impl IntoRequest<EchoRequest>, ) -> Result<Response<EchoResponse>, Status>

pub async fn preverify( &mut self, request: impl IntoRequest<PreverifyRequest>, ) -> Result<Response<PreverifyResponse>, Status>

pub async fn execute_state_transition( &mut self, request: impl IntoRequest<ExecuteStateTransitionRequest>, ) -> Result<Response<ExecuteStateTransitionResponse>, Status>

pub async fn verify_state_transition( &mut self, request: impl IntoRequest<VerifyStateTransitionRequest>, ) -> Result<Response<VerifyStateTransitionResponse>, Status>

pub async fn accept( &mut self, request: impl IntoRequest<StateTransitionRequest>, ) -> Result<Response<StateTransitionResponse>, Status>

pub async fn finalize( &mut self, request: impl IntoRequest<StateTransitionRequest>, ) -> Result<Response<StateTransitionResponse>, Status>

pub async fn revert( &mut self, request: impl IntoRequest<RevertRequest>, ) -> Result<Response<RevertResponse>, Status>

pub async fn persist( &mut self, request: impl IntoRequest<PersistRequest>, ) -> Result<Response<PersistResponse>, Status>

pub async fn get_provisioners( &mut self, request: impl IntoRequest<GetProvisionersRequest>, ) -> Result<Response<GetProvisionersResponse>, Status>

pub async fn get_state_root( &mut self, request: impl IntoRequest<GetStateRootRequest>, ) -> Result<Response<GetStateRootResponse>, Status>

pub async fn get_notes_owned_by( &mut self, request: impl IntoRequest<GetNotesOwnedByRequest>, ) -> Result<Response<GetNotesOwnedByResponse>, Status>

pub async fn get_notes( &mut self, request: impl IntoRequest<GetNotesRequest>, ) -> Result<Response<Streaming<GetNotesResponse>>, Status>

Streams notes from a given block height, optionally filtered by the given view key. If the view key is not present, all notes will be streamed.

pub async fn get_anchor( &mut self, request: impl IntoRequest<GetAnchorRequest>, ) -> Result<Response<GetAnchorResponse>, Status>

pub async fn get_opening( &mut self, request: impl IntoRequest<GetOpeningRequest>, ) -> Result<Response<GetOpeningResponse>, Status>

pub async fn get_stake( &mut self, request: impl IntoRequest<GetStakeRequest>, ) -> Result<Response<GetStakeResponse>, Status>

pub async fn find_existing_nullifiers( &mut self, request: impl IntoRequest<FindExistingNullifiersRequest>, ) -> Result<Response<FindExistingNullifiersResponse>, Status>